#
# spec file for package gnome-clocks
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-clocks
Version:        47.0
Release:        1.4
Summary:        Clock application designed for GNOME 3
License:        GPL-2.0-or-later
Group:          Productivity/Office/Other
URL:            https://live.gnome.org/Design/Apps/Clock
Source0:        %{name}-%{version}.tar.zst
BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.55.1
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(geocode-glib-2.0)
BuildRequires:  pkgconfig(gio-2.0) >= 2.58
BuildRequires:  pkgconfig(glib-2.0) >= 2.58
BuildRequires:  pkgconfig(gnome-desktop-4) >= 3.8
BuildRequires:  pkgconfig(gobject-2.0) >= 2.58
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gsound) >= 0.98
BuildRequires:  pkgconfig(gtk4) >= 4.5
BuildRequires:  pkgconfig(gweather4) >= 3.32.0
BuildRequires:  pkgconfig(libadwaita-1) >= 1.0
BuildRequires:  pkgconfig(libgeoclue-2.0) >= 2.4

%description
A nice simple app to show the time, date, and alarms.

%package -n gnome-shell-search-provider-gnome-clocks
Summary:        GNOME Clocks -- Search Provider for GNOME Shell
Group:          Productivity/Office/Other
Requires:       %{name} = %{version}
Supplements:    (gnome-shell and %{name})
BuildArch:      noarch

%description -n gnome-shell-search-provider-gnome-clocks
This package contains a search provider to enable GNOME Shell to get
search results from GNOME Clocks.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}/%{_datadir}

%check
%meson_test

%files
%license LICENSE.md
%doc README.md NEWS
%doc %{_datadir}/help/C/gnome-clocks/
%{_bindir}/%{name}
%{_datadir}/metainfo/org.gnome.clocks.metainfo.xml
%{_datadir}/dbus-1/services/org.gnome.clocks.service
%{_datadir}/glib-2.0/schemas/org.gnome.clocks.gschema.xml
%{_datadir}/icons/hicolor/*/apps/org.gnome.clocks*
%{_datadir}/applications/org.gnome.clocks.desktop

%files -n gnome-shell-search-provider-gnome-clocks
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/gnome-shell/search-providers/org.gnome.clocks.search-provider.ini

%files lang -f %{name}.lang

%changelog
* Fri Sep 20 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.0:
  + Port to new libadwaita widgets.
  + Updated translations.
- Switch to source service.
* Fri Mar 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Updated translations.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.rc:
  + Add mnemonic to Start button.
  + Disable alarm after ringing when not set to repeat.
  + Fix countdown timer progress during suspend.
  + Fix resume bug on clear button pressed.
  + Fix sorting of locations.
  + Improve app metainfo for AppStream 1.0.
  + Show a toast when a new alarm is set.
  + Updated translations.
* Sun Sep 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + Port to new libadwaita widgets, including breakpoints
  + Bundle bell sounds
  + GNOME Shell search provider performance improvements
  + Improve location matching by normalizing location search
    strings
  + Replace deprecated code paths
  + Use xdg-desktop-portal to get system clock format
  + Updated translations.
* Fri Mar 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Updated translations.
* Sun Mar  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + Updated translations.
* Fri Feb 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + Display seconds in the world clock detail view
  + Reset snooze time when disabling alarms
  + Add mnemonics to the view switcher
  + Say ahead/behind instead of later/earlier
  + Fix button layout in the timer view
  + Add missing ellipses to button labels
  + Remove an incorrect tooltip
  + Help fixes
  + Updated translations.
* Wed Oct  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Package sub-package gnome-shell-search-provider-gnome-clocks as
  noarch.
* Tue Sep 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Updated translations.
* Sun Aug  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta:
  + Port to AdwAboutWindow
  + Fix notifications are immediately withdrawn.
  + Updated translations.
* Mon Jul 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.alpha:
  + Build against either geocode-glib-1.0 or geocode-glib-2.0.
  + Disable "Add" button by default on new timer dialog.
  + Fix the incorrect order of stopwatch's time label using RTL
    locale.
  + Do not match timezones on search.
- Replace pkgconfig(geocode-glib-1.0) with
  pkgconfig(geocode-glib-2.0) BuildRequires following upstream
  changes.
* Sun Mar 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Updated translations.
* Mon Feb 14 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Use newer GClue to avoid sandbox hole
  + Updated translations.
* Fri Jan 14 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.alpha:
  + Codebase is now ported to GTK 4 and Libadwaita.
  + Updated translations.
- Update BuildRequires, following upstreams port to GTK4:
  + Replace pkgconfig(gnome-desktop-3.0) with
    pkgconfig(gnome-desktop-4).
  + Replace pkgconfig(gtk+-3.0) with pkgconfig(gtk4).
  + Replace pkgconfig(libhandy-1) with pkgconfig(libadwaita-1).
  + Replace pkgconfig(gweather-3.0) with pkgconfig(gweather-4).
* Wed Jan 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add appstream-glib, desktop-file-utils BuildRequires and check
  section and meson_test macro, run tests during build.
- Modernize our Supplements to current standard.
* Sun Oct 17 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + Updated translations.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Wed Mar 24 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + No changes.
* Tue Feb 16 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.beta:
  + World Location Dialog: Match HdyStatusPage styling.
  + Added ALT + 1,2,3,4 navigation between pages.
  + Various Bugfixes.
  + Updated translations.
* Wed Sep 16 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Alarms: Allow setting snooze/ring duration.
  + World: Redesign the Add World Clock dialog.
  + Various design refinement.
* Tue Sep  1 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.37.91:
  + Updated translations.
- Changes from version 3.37.90:
  + World: Redesign the Add World Clock dialog.
  + Various design refinement.
- Replace pkgconfig(libhandy-0.0) BuildRequires with
  pkgconfig(libhandy-1): follow upstreams port to new libhandy API.
* Sun May 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2:
  + World: Handle impossible places.
  + Timer: Fix signal for updating the duration.
* Thu Mar  5 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + Major redesign of the application.
  + Multiple timers support.
  + Daylight status for World clocks.
  + Adaptive layout: Mobile support.
  + Updated translations.
- Add pkgconfig(libhandy-0.0) BuildRequires: New dependency.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Sep 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + Updated translations.
* Sun Sep  1 2019 mgorse@suse.com
- Update to version 3.33.1:
  + Expose world clock locations to gnome-shell.
  + Updated translations.
- Remove /usr/share/gnome-clocks from files: images have been
  moved to a GResource.
* Sun Mar 10 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Sun Jan  6 2019 bjorn.lie@gmail.com
- Update to version 3.31.2:
  + Update icon.
  + Updated translations.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.1:
  + Replace Appmenu with a menu button.
  + Update icon.
  + Various bug fixes.
  + Updated translations.
- Drop upstream fixed patches:
  + gnome-clocks-timer-Set-width-chars2.patch.
  + gnome-clocks-timer-fixes.patch.
* Fri Dec 28 2018 bjorn.lie@gmail.com
- Add upstream bug fix patches from stable branch:
  + gnome-clocks-timer-Set-width-chars2.patch: timer: Set
    width-chars=2 property on the spinbuttons.
  + gnome-clocks-timer-fixes.patch: Various backported timer fixes.
* Wed Oct 24 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Flatpak package improvements.
* Sat Sep  1 2018 bjorn.lie@gmail.com
- Update to version 3.30.0:
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Sat Mar 10 2018 bjorn.lie@gmail.com
- Update to version 3.28.0:
  + Search: workaround crash due to libgweather serialization.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sun Dec 24 2017 luc14n0@linuxmail.org
- Update to version 3.27.1:
  + World clocks: add UTC and "Anywhere on Earth" clocks.
  + Updated translations.
- Add glib-2.0 and gobject-2.0 pkgconfig BuildRequires. Note that
  they were being pulled with gio-2.0 pkgconfig module and used
  already as all of them live in glib2-devel package.
- Drop %%glib2_gsettings_schema_*, %%icon_theme_cache_* and
  %%desktop_database_* post/postun scriptlets and
  %%glib2_gsettings_schema_requires macro. They are no longer needed
  since RPM file triggers.
- Following the above, drop hicolor-icon-theme BuildRequires, no
  longer needed.
- Drop update-desktop-files BuildRequires and stop using
  suse_update_desktop_file macro, not needed.
- Add fdupes BuildRequires and pass corresponding fdupes macro,
  silence rpmlint.
- Do a minor spec cleanup.
* Sun Oct 15 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + Updated translations.
* Sun Sep 10 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + build: fix installation of locale data.
  + Updated translations.
* Sun Aug 20 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Updated translations.
* Fri Jul  7 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + Converted World clocks and Alarms to GtkFlowBox.
  + Require Meson 0.41.0.
  + Updated translations.
- Drop gnome-clocks-fix-icons-install.patch: Fixed upstream.
* Thu May 18 2017 zaitor@opensuse.org
- Update to version 3.25.1:
  + World clocks: show state name when available.
  + Switched to the Meson build system.
  + Updated translations.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Add gnome-clocks-fix-icons-install.patch: Fix icons install.
* Sat Mar 18 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + Withdraw notifications when the application receives focus.
  + Misc bugfixes.
  + Updated translations.
* Fri Feb  3 2017 zaitor@opensuse.org
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Mon Oct 10 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Misc bugfixes.
  + Updated translations.
* Sun Sep 18 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Sat Sep  3 2016 zaitor@opensuse.org
- Update to version 3.21.2:
  + Fix RTL problem in timer.
  + Updated translations.
* Sat Sep  3 2016 zaitor@opensuse.org
- Update to version 3.21.1:
  + Drop intltool in favour of new gettext.
  + Updated translations.
- Drop intltool BuildRequires following upstream changes.
* Sat Sep  3 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Misc bugfixes.
  + Updated translations.
* Sun May  8 2016 badshah400@gmail.com
- Update to version 3.20.1 (fate#318572):
  + Rework gnome-shell search provider to be stateless.
  + Updated translations.
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Sun Mar 20 2016 zaitor@opensuse.org
- Update to version 3.20.0:
  + Save and restore window size correctly with new GTK.
  + Updated translations.
* Sun Feb 21 2016 zaitor@opensuse.org
- Update to version 3.19.2:
  + Adapt to GTK changes.
  + Add HighContrast theme variant.
  + Refactor internals to use GListModel.
  + Updated translations.
* Sun Dec 20 2015 zaitor@opensuse.org
- Update to version 3.19.1:
  + Adapt to GTK changes.
  + Improve keyboard shortcuts and add overlay panel.
- Replace pkgconfig(geoclue-2.0) for pkgconfig(libgeoclue-2.0)
  BuildRequires following upstream changes.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Release to sync with new GNOME release.
  + Misc bugfixes.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.16.2:
  + Fix redraw issue with newer GTK+.
  + Improve geolocation icon with Hi-DPI displays.
  + Updated translations.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + New HighContrast SVG icon.
  + Updated translations.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Misc bugfixes.
  + Updated translations.
* Thu Feb 19 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Updated translations.
* Fri Nov 28 2014 zaitor@opensuse.org
- Update to version 3.15.1:
  + Expose an add-location action to be used by GNOME Maps.
  + Use gsound library to play sounds.
  + Misc bugfixes.
  + Updated translations.
- Replace pkgconfig(libcanberra) for pkgconfig(gsound)
  BuildRequires: Following upstream.
* Mon Oct 13 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Fix runtime warnings in the search provider.
  + Updated translations.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Fix a CSS problem in RTL mode.
* Wed Sep 17 2014 dimstar@opensuse.org
- Update to version 3.13.92:
  + Misc bugfixes.
  + Updated translations.
* Sun Sep  7 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Bump libgweather dependency.
  + Misc bugfixes.
  + Updated translations.
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 3.13.2:
  + Implement a gnome-shell search provider to search world clocks.
  + Sort world clocks by timezone.
  + Misc bugfixes.
  + Updated translations.
- Drop 0001-Sort-locations-by-timezone.patch: fixed upstream.
- Add new subpackage gnome-shell-search-provider-gnome-clocks.
* Wed Jul 23 2014 mgorse@suse.com
- Add 0001-Sort-locations-by-timezone.patch: sort locations by
  timezone (bnc#861982, bgo#701169).
* Tue Jul 22 2014 dimstar@opensuse.org
- Update to version 3.13.1:
  + Update to work with the new adwaita theme.
  + Rework a little the stopwatch laps table.
  + Ensure numbers in the timer do not move during transition.
  + Updated translations.
* Mon Mar 24 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Sat Mar 22 2014 zaitor@opensuse.org
- Update to version 3.11.92:
  + Misc bugfixes.
  + Updated translations.
* Tue Feb 18 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Use headerbar in dialogs.
  + Detect when trying to add a duplicate alarm.
  + Misc bugfixes.
  + Updated translations.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + Port to the new GLib notification API.
  + Misc bugfixes.
  + Updated translations.
- Drop pkgconfig(libnotify) BuildRequires: no longer required.
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Misc bugfixes.
  + Updated translations.
* Mon Sep 23 2013 zaitor@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Add geolocation support.
  + Add user manual.
  + Misc bugfixes.
  + Updated translations.
- Add yelp-tools BuildRequires: required to build the new user
  manual.
- Add pkgconfig(geoclue-2.0) andpkgconfig(geocode-glib-1.0)
  BuildRequires: new dependencies for geolocation support.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Tweak some details of the new ui.
  + Add an appdata file for gnome-software.
  + Misc bugfixes.
  + Updated translations.
- Remvoe gnome-clocks.gresource.xml source: it's now included in
  the tarball.
* Mon Aug 19 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Add analogic progress to stopwatch and timer.
  + Rework stopwatch layout using a list box.
  + Blink when the timer is paused.
  + Fix many problems with right-to-left languages.
  + Misc bugfixes.
  + Updated translations.
- Add gnome-clocks.gresource.xml: the file was missing from the
  tarball.
* Sat Aug  3 2013 zaitor@opensuse.org
- Update to version 3.9.3:
  + Adapt to the latest GTK+ and Vala changes.
  + Misc bugfixes.
  + Updated translations.
* Sun Jun 23 2013 zaitor@opensuse.org
- Update to version 3.9.2:
  + Use latest libgweather (new search entry).
  + Misc bugfixes.
  + Updated translations.
* Sun Jun 16 2013 zaitor@opensuse.org
- Update to version 3.9.1:
  + Use client-side decorations for the window close button.
  + Reworked selection design.
  + Use latest gtk (ui templates, drop libgd).
  + Updated translations.
* Tue May 14 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Prevent creation of world clocks for locations without timezone
    data.
  + Misc bugfixes.
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Misc bugfixes.
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Rework some of the code to use latest libgd.
  + Misc bugfixes.
  + Updated translations.
* Thu Mar 14 2013 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Wed Mar  6 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Actually update the world clocks.
  + Show Stop/Snooze in the alarm notification.
  + Many small ui fixes.
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Switch to GNOME version number.
  + Full rewrite in Vala.
  + Various changes to the visual design (especially World and
    Alarm).
  + Many bugfixes and improvements made possible by the rewrite.
- Replace BuildRequires to follow the rewrite from python to vala:
  + Old ones: python, pkgconfig(pycairo), pkgconfig(pygobject-3.0),
    gobject-introspection.
  + New ones: vala, pkgconfig()-style: gio-2.0, gnome-desktop-3.0,
    gtk+-3.0, gweather-3.0, libcanberra, libnotify,
    gobject-introspection-1.0.
- No longer mark the package as noarch, as it is now native code.
* Tue Feb  5 2013 dimstar@opensuse.org
- Update to version 0.1.6:
  + Reworked the alarms panel (design is still in progress).
  + Implemented disabled alarms.
  + Depend on newer GWeather.
  + Ported to Python 3.
  + Ported to autotools.
  + Move configuration to GSettings.
  + Remove pyxdg dependency.
  + Misc bugfixes.
  + Updated translations.
- Change build and install section to use configure / make install.
- Add glib schema handling to post/postun.
- Drop python-xdg Requires: no longer needed.
* Tue Dec  4 2012 dimstar@opensuse.org
- Update to version 0.1.5:
  + Reworked large parts of the code to use less CPU.
  + Depend on libgnome-desktop to use the system WallClock.
  + Show the nation beside the city.
  + Improved rendering of world clocks and alarms.
  + Misc bugfixes.
  + Updated translations.
- Add python-xdg Requires: It's imported from gnomeclocks/utils.py.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 0.1.4:
  + Misc bugfixes.
  + Updated translations.
* Sat Sep 29 2012 zaitor@opensuse.org
- Update to version 0.1.3:
  + Implement "laps" in the stopwatch.
  + Misc bugfixes.
  + Updated translations.
- Changes from version 0.1.2:
  + Use vertical spinbuttons for the timer setup.
  + Fix timezone offset calculation during DST.
  + Misc bugfixes.
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 0.1.1:
  + Start week on the right day specified by the current locale.
  + Use the correct location for pixmaps by default.
  + Misc bugfixes.
  + Updated translations.
* Sun Sep  2 2012 dimstar@opensuse.org
- Initial package, version 0.1.0.
